OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registrando",
    "Log Reader" : "Lector de Bitácoras",
    "A log reader for Nextcloud" : "Un lector de registros para Nextcloud.",
    "Log reader for Nextcloud" : "Lector de registros para Nextcloud.",
    "Level" : "Nivel",
    "App" : "Aplicación",
    "Time" : "Hora",
    "Line {line}" : "Línea {line}",
    "Download logs" : "Descargar bitácoras",
    "Ctrl" : "Ctrl",
    "Relative" : "Relativo",
    "Application" : "Aplicación",
    "Message" : "Mensaje",
    "Show details" : "Mostrar detalles",
    "Debug" : "Depuración",
    "Info" : "Info",
    "Warning" : "Advertencia",
    "Error" : "Error",
    "Fatal" : "Fatal",
    "Error parsing log" : "Error al interpretar la bitácora",
    "Caused by " : "Causado por",
    "Copy" : "Copiar",
    "Copy raw" : "Copiar sin formato",
    "Copy formatted" : "Copiar con formato",
    "No server logs" : "No hay bitácoras del servidor",
    "One or more entries are hidden by the log level filter" : "Uno o más elementos están ocultos por el filtro del nivel de bitácora",
    "Everything is working fine" : "Todo está funcionado correctamente",
    "Load log file" : "Cargar archivo de registro",
    "Invalid log file" : "Archivo de registro inválido",
    "Log levels" : "Niveles de bitácoras",
    "Log content" : "Contenido de bitácoras",
    "Live update" : "Actualización en vivo"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
